/**
 * Copyright 2016-present, Deloitte Digital.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-3-Clause license found in the
 * LICENSE file in the root directory of this source tree.
 */

declare module ReactHabitat {

    export interface IDomFactory {
        /**
         * An identifier string for the type of components this injects
         */
        identifier: () => string;
        /**
         * The inject method after a wire-up has been requested
         * @param {*}           module      - The component
         * @param {object}      props       - The components properties
         * @param {Element}     target      - The element to inject the component into
         */
        inject?: (module: any, props: {}, target: Element) => void;
    }

    export interface IContainer {
        /**
         * Register a new component in the container
         * @param {string}      name        - The key that identifies this component
         * @param {*}           comp        - The component class
         */
        registerComponent: (name: string, comp: any) => void;
        /**
         * Get a registered component for a key
         * @param {string}      name        - The key name of the component that has been registered
         */
        resolve: (name: string) => any;
    }

    export interface IBootstrapper {
        factory: IDomFactory;
        setContainer: (container: IContainer) => void;
    }

    export class Bootstrapper implements IBootstrapper {
        factory: IDomFactory;
        setContainer: (container: IContainer) => void;
        componentSelector: string;
        elements: NodeListOf<Element>;
        _container: IContainer;
    }

    export class Container implements IContainer {
        registerComponent: (name: string, comp: any) => void;
        resolve: (name: string) => any;
    }

}